@@ -14,10 +14,10 @@ function(formula, link = c("identity", "log", "logit"), distribution = c("normal
         fit <- list(coefficients = NULL, logLik = NULL, hessian = NULL, k = NULL, n = n)
     } else{
         distr <- match.arg(distribution)
-        if(is.null(df) && distr == "lt")
-            stop("You must specify the degrees of freedom for the logit-t distribution.\n")
-        if(!is.null(df) && distr != "lt")
-            warning("you specified the `df' argument and you don't use the `logit-t' as reference distribution.\n")
+        if(is.null(df) && distr == "t")
+            stop("You must specify the degrees of freedom for the Student's-t distribution.\n")
+        if(!is.null(df) && distr != "t")
+            warning("you specified the `df' argument and you don't use the Student's-t as reference distribution.\n")
         link <- match.arg(link)
         X <- model.matrix(mt, mf)
         fit <- grouped.fit(y, X, link, distr, df, starts = str.values, iter)
